@@ -1,17 +1,8 @@
-#!/usr/bin/env python
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
-
-import sys
-import os
-DIR = os.path.abspath(os.path.normpath(os.path.join(__file__,
-    '..', '..', '..', '..', '..', 'trytond')))
-if os.path.isdir(DIR):
-    sys.path.insert(0, os.path.dirname(DIR))
-
 import unittest
+import doctest
 from decimal import Decimal
-
 import trytond.tests.test_tryton
 from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT, test_view,\
     test_depends
@@ -19,9 +10,7 @@ from trytond.transaction import Transaction
 
 
 class StockSplitTestCase(unittest.TestCase):
-    '''
-    Test Stock Lot module.
-    '''
+    'Test Stock Lot module'
 
     def setUp(self):
         trytond.tests.test_tryton.install_module('stock_split')
@@ -34,21 +23,15 @@ class StockSplitTestCase(unittest.TestCase):
         self.move = POOL.get('stock.move')
 
     def test0005views(self):
-        '''
-        Test views.
-        '''
+        'Test views'
         test_view('stock_split')
 
     def test0006depends(self):
-        '''
-        Test depends.
-        '''
+        'Test depends'
         test_depends()
 
     def test0010split(self):
-        '''
-        Test split.
-        '''
+        'Test split'
         with Transaction().start(DB_NAME, USER, context=CONTEXT):
             unit, = self.uom.search([('name', '=', 'Unit')])
             template, = self.template.create([{
@@ -64,7 +47,9 @@ class StockSplitTestCase(unittest.TestCase):
                         }])
             input_, = self.location.search([('code', '=', 'IN')])
             storage, = self.location.search([('code', '=', 'STO')])
-            company, = self.company.search([('rec_name', '=', 'B2CK')])
+            company, = self.company.search([
+                    ('rec_name', '=', 'Dunder Mifflin'),
+                    ])
             self.user.write([self.user(USER)], {
                     'main_company': company.id,
                     'company': company.id,
@@ -126,11 +111,8 @@ def suite():
     suite = trytond.tests.test_tryton.suite()
     from trytond.modules.company.tests import test_company
     for test in test_company.suite():
-        if test not in suite:
+        if test not in suite and not isinstance(test, doctest.DocTestCase):
             suite.addTest(test)
     suite.addTests(unittest.TestLoader().loadTestsFromTestCase(
             StockSplitTestCase))
     return suite
-
-if __name__ == '__main__':
-    unittest.TextTestRunner(verbosity=2).run(suite())
